# Multiline Ingredients

---

- This is a long ingredient

  it spans multiple paragraphs
  
  this may be unusual but is valid
  
  
- this is a normal boring ingredient


- *5ml* is an amount that

  is the amount of *this* ingredient
  
- *5 grams*
  
  is an amount that stands alone on the first line
  
- [this is a link](some other recipe)


- [this is not a link](some other recipe) 

  since links must wrap the whole ingredient text